# Joking

![Logo](https://res.cloudinary.com/dll6vnzkb/image/upload/v1661657421/Joking_i6u5ks.png)

```python
>>>import Joking
>>>random_dad_joke()
My friend told me that pepper is the best seasoning for a roast, but I took it with a grain of salt.
>>>programming_joke()
The glass is neither half-full nor half-empty, the glass is twice as big as it needs to be.
>>>random_joke()
Why does Santa go down the chimney?

Because it soots him!
>>>random_knock_knock_joke()
knock knock joke example
>>>print("bye")
bye
```


Joking is a python library for getting random dad jokes and more kinds
of jokes v3.1.3

![image0](https://img.shields.io/badge/build-Passing-green?style=for-the-badge)
![forthebadge](https://forthebadge.com/images/badges/gluten-free.svg)
![forthebadge2](https://forthebadge.com/images/badges/powered-by-electricity.svg)
![image3](https://img.shields.io/badge/License-MIT-orange?style=for-the-badge)
![image4](https://bit.ly/3cTlr54)
![forthebadge](https://forthebadge.com/images/badges/made-with-python.svg)
![image7](https://tinyurl.com/emails83) 
![PyPI - Downloads](https://static.pepy.tech/personalized-badge/joking?period=total&style=for-the-badge&units=none&left_color=black&right_color=orange&left_text=Downloads)
![image](https://img.shields.io/badge/coverage-100%25-green?style=for-the-badge&labelColor=black)

# Installation

you can install it by using the [pip](https://pip.pypa.io/en/stable/)
package manager

``` bash
pip install Joking
```

# How to Use


``` python
Multiple_Jokes(i) #i is for the amount of dad jokes
```

``` python
random_dad_joke() #prints out a random dad joke
```

``` python
programming_joke() #prints a random programming joke
```

``` python
random_joke() #prints a random joke
```

``` python
sjoke() #Gets a specific joke using the joke id from https://icanhazdadjoke.com/
```

```  python
search_for_joke() #prints the top result for the joke you searched
```

```python
JOD() #Gets the joke of the day
```

``` python
Random_knock_knock_joke() #gets a random knock knock joke
```

``` python
skkjoke() #Gets a specific knock knock joke using the joke id
```

``` python
DarkJoke() #Gets a dark joke that is potentially sexist or racist
```

``` python
Pun() #Gets a random pun
```

``` python
Submit_joke() #submits a joke
```

``` python
yo_mama_joke_slash_insults() #Gets a random Yo mama joke or insult
```
```python
animal_joke() #Gets a random animal Joke
```

```python
chuck_norris_joke() #Gets a chuck noris joke? (I don't even know what a chuck noris joke is)
```
```python
Meme() #Gets a meme from reddit
```
```python
make_meme() #Makes a meme
```

```python
Irony_Joke() #gives funny irony joke
```

```python
Irony_Joke_By_ID() #gives funny irony joke by ID
```

```python
Law_Joke() #Gets a law joke
```

```python
Law_Joke_By_ID() # just like Irony_Joke_By_ID() but with law jokes
```

# F.A.Q.

Q. *Who make's The Jokes?*

A. **The whole of the internet**

Q. *Are some jokes Inappropriate?*

A. **No, Most Joke's with the exception of Dark and some Law Jokes are not Inappropriate.**

Q. *How do I contact you?*

A. **h**

# How it works

It works by web scraping https://icanhazdadjoke.com/, jokes4us.com and using version
2 of jokeapi.dev 

# Joke id's

Joke ids are Joke ids from icanhazdadjoke.com or from
http://www.jokes4us.com/knockknockjokes/random/knockknock{id go here}.html To find
a jokes id just search icanhazdadjoke.com or find the knock knock joke
you want from
http://www.jokes4us.com/knockknockjokes/index.html

# How to contribute


- Start by going to https://github.com/Iwertyuiop123653/Joker
- Then fork the repository
- make the changes you want
- Then commit

# Coming Soon
Something

# Contact

hahacoolguystacos@gmail.com or contact me via this form -> https://bit.ly/3CFTHeX